@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "completionorderwidget.h"
-using namespace Qt::Literals::StringLiterals;
+#include <kldapcore/ldapactivitiesabstract.h>
 
 #include <KDescendantsProxyModel>
 #include <KLDAPCore/LdapClient>
@@ -33,6 +33,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QVBoxLayout>
 
 using namespace PimCommon;
+using namespace Qt::Literals::StringLiterals;
 
 CompletionOrderEditorAdaptor::CompletionOrderEditorAdaptor(QObject *parent)
     : QDBusAbstractAdaptor(parent)
@@ -94,7 +95,7 @@ protected:
     }
 
 private:
-    KLDAPCore::LdapClient *mLdapClient = nullptr;
+    KLDAPCore::LdapClient *const mLdapClient;
     int mWeight;
 };
 
@@ -333,6 +334,12 @@ void CompletionOrderWidget::loadCompletionItems()
         // The first step is to gather all the data, creating CompletionItem objects
         const QList<KLDAPCore::LdapClient *> listClients = mLdapSearch->clients();
         for (KLDAPCore::LdapClient *client : listClients) {
+            if (mLdapActivities) {
+                if (mLdapActivities->hasActivitySupport())
+                    if (client->server().enablePlasmaActivities() && !client->server().activities().contains(mLdapActivities->currentActivity())) {
+                        continue;
+                    }
+            }
             new CompletionViewItem(mListView, new LDAPCompletionItem(client));
         }
     }
@@ -368,6 +375,11 @@ void CompletionOrderWidget::loadCompletionItems()
     mDirty = false;
 }
 
+void CompletionOrderWidget::setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities)
+{
+    mLdapActivities = ldapActivities;
+}
+
 void CompletionOrderWidget::setLdapClientSearch(KLDAPCore::LdapClientSearch *ldapSearch)
 {
     mLdapSearch = ldapSearch;
